Handling MRIO data
-------------------

.. toctree::
  :maxdepth: 2

  notebooks/pymrio_directly_assign_attributes
  notebooks/working_with_wiod
  notebooks/working_with_exiobase
  notebooks/working_with_eora26
  notebooks/working_with_oecd_icio
  notebooks/load_save_export
  notebooks/aggregation_examples
  notebooks/buildflowmatrix
  notebooks/stressor_characterization
  notebooks/advanced_group_stressors
